@@ -1,5 +1,5 @@
-# nolint start
 library(mlr3)
+library(checkmate)
 library(mlr3misc)
 library(mlr3pipelines)
 library(paradox)
@@ -7,4 +7,3 @@ library(R6)
 
 lapply(list.files(system.file("testthat", package = "mlr3"), pattern = "^helper.*\\.[rR]", full.names = TRUE), source)
 lapply(list.files(system.file("testthat", package = "mlr3tuning"), pattern = "^helper.*\\.[rR]", full.names = TRUE), source)
-# nolint end
